;12AD.ASM (AES11 Program)
;
;The 68HC11 has two serial interface systems.  One is the SCI which
;we use for the RS-232 communications.  The other is the SPI which
;is intended for control of peripheral devices.  This system is similar
;to the well known Philips I2C serial interface.  Many devices are
;now being made which use 2 or 3 wire serial control.  The Linear
;Technology LCT1268 12-bit A/D converter is one of them. Notice on the
;AES-11 D/A converter we use the 8 data lines to send data to the chip.
;On the LCT1268 we use one data line with a clock to receive information.
;Here is an example of how we use the SPI system. 
;
;Program sets up the HC11 's SPI system to communicate with the LTC1286
;which performs 12bit A/D conversion and returns data back to the HC11
;on a serial data line.

;
;                    LTC1286                 MC68HC11
;                   .-------.             .--------------.
;                   |       |             |              |
;                   |  12   |<---CLK------| PD.4  (SCK)  |
; Vin--[10K]---.--->|  Bit  |             |              |
;              |    |  A/D  |----Dout---->| PD.2  (MISO) |
;          + -----  |       |    __       |              |
;      1uF - -----  |       |<---CS-------| PD.5   (SS)  |
;              |    |_______|             |______________|
;              |      slave                   master
;             GND

;Assemble and Run Program
;AS11 12AD.ASM
;B 0100


; Assembler 's Directives
; These are the offset addresses for the HC11 I/O Register.
; Base address for I/O Register on the AES-11 is at 6000H

SPCR    EQU     $28             ;SPI Control Register
SPDR    EQU     $2A             ;SPI Data Register
SPSR    EQU     $29             ;SPI Status Register
DDRD    EQU     $09             ;Data Direction Register for PORTD
PORTD   EQU     $08             ;PORT D Data Register



        ORG     $100
        JMP     MAIN

RES1    RMB     1               ;The 2 bytes measured from 12-bit
RES2    RMB     1               ;A/D will be stored here.
                                ;RES1 contains the most significant byte
                                ;of A/D Data
                                ;RES2 contains the least significant byte.

                                
        ORG     $200
MAIN:

                                ;Initialize the SPI system on the HC11.
        LDX     #$6000          ;Base Address of I/O Registers.
        LDAA    #$38            ;Configure Data.
        STAA    DDRD,X          ;Write to DDRD register ($6009)
                                ;to configure PORTD pins.

        LDAA    #$5B            ;SPI on the AES-11 is a master device
        STAA    SPCR,X          ;CPOL = 1, CPHA = 0; E/32
                                ;clock polarity, clock phase select,
                                ;SPI Clock (SCK) Rate 

        BSET    $08,X $20       ;set SS (PD.5) pin high to make sure 
                                ;that the master device is not select
                                ;the slave device.

                                ;end of initialization

;ready to read 12 bit A/D conversion

        BCLR   PORTD,X $20      ;SS (PD.5) goes low to select the
                                ;A/D device.

        STAA    SPDR,X          ;write out anything to the SPDR ($602A)
                                ;to start SCK (PD.4)
LOOP
        LDAB    SPSR,X          ;read SPI status register ($6029)
        BPL     LOOP            ;loop until bit 7 set.
                                ;bit 7 set indicates that the data is
                                ;transfered completely.

        LDAA    SPDR,X          ;READ the FIRST BYTE of 12-bit A/D
                                ;READ also clears the flag.

        STAA    RES1            ;SAVE in memory

        STAA    SPDR,X          ;start the process again

LOOP2
        LDAB    SPSR,X          ;read SPI status register ($6029)
        BPL     LOOP2           ;loop until flag set.

        LDAA    SPDR,X          ;read the 2nd byte of 12-bit A/D DATA
        STAA    RES2            ;and stores in memory

        BSET    PORTD,X $20     ;set SS line high to disable communication
                                ;between the AES-11 & LTC1286

        RTS                     ;program ends

        END







