;50HZB.ASM (2nd version)
;Generate a 50Hz square wave at PA6/OC2 pin
;program is similar to 50HZ.ASM but use interrupt service routine
;The advantage for using interrupt service routine to toggle a pulse is 
;that the microprocessor can have free time to run other programs to
;do other different tasks simultaneously. In this sample program, it setups 
;the interrupt service routine to response for a timer interrupt and
;returns to the Debugger Prompt continue working on its previous task.
;At the Debugger Prompt, the user can upload programs to perform tasks 
;while the timer been running in the background; toggles pin on successful 
;time comparision to generate a 50Hz square wave.

;HC11 I/O REGISTERS

TCTL1   EQU     $6020           ;Timer Control Register 1
TFLG1   EQU     $6023           ;Main Timer Interrupt Flag Register 1
TMSK1   EQU     $6022           ;Main Timer Intterrupt Mask Register 1
TOC2    EQU     $6018           ;Timer Output Compare Register 2


PTOC2   EQU     $00DC           ;PSEUDO VECTOR FOR TIMER 2 OUTPUT COMPARATOR
                                ;(see user's manual for location
                                ; of pseudo vector)
                               
        ORG     $100

        LDX     #SVOC2          ;address for OC2 service routine in RAM

        LDAA    #$7E            ;JMP OP-Code
        STAA    PTOC2           
        STX     PTOC2+1         ;7E nn nn  setup jmp vector for OC2
                                ;service routine

        
                                ;setup TCTL1 register
        LDAA    #$40            ;OM2:OL2  =  0:1
        STAA    TCTL1           ;Toggle OCx Pin on Successful Compare

        LDAA    #%01000000      ;
        STAA    TFLG1           ;Clear any old OC2F flag

        LDAA    #%01000000
        STAA    TMSK1           ;Enable OC2 interrupts,

        RTS                     ;program ends; returns to the Debugger


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;codes for OC2 interrupt
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
SVOC2   
        LDD     TOC2                        
        ADDD    #$2400          ;ADD DELAY (T/2)
        STD     TOC2            ;Update OC2 (schedule next edge)
        LDAA    #$40
        STAA    TFLG1           ;clear OC2F 
        RTI                     ;Return from OC2 service

        END
