;clock.asm
;program uses real time interrupt to display a clock

;HC11 I/O REGISTERS

TFLG2   EQU     $25             ;Misc. Timer Interrupt Flag Register 
TMSK2   EQU     $24             ;Misc. Timer Interrupt Mask Register 2


PREALI  EQU     $EB             ;RTII pseudo interrupt vector

FCNT    EQU     122             ;number of RTII interrupts to
				;make 1 second
				
			       
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	ORG     $100
	JMP     MAIN

HR      ZMB     1               ;HOUR count in BCD
MIN     ZMB     1               ;MINute count in BCD
SEC     ZMB     1               ;Second count in BCD

FSEC    ZMB     2               ;FSEC is fraction of second count
				;for RTII routine in hex

	ORG     $200
MAIN
	LDX     #RRTII          ;address for RTII service routine in RAM

	LDAA    #$7E            ;JMP OP-Code
	STAA    PREALI           
	STX     PREALI+1        ;7E nn nn  setup jmp vector for RTII
				;service routine
	LDX     #$6000          ;I/O Base Register
	LDAA    #$40
	STAA    TMSK2,X         ;set RTII flag
	CLI
	CLR     FSEC
	CLR     FSEC+1
L1
	JSR     DISPLAY         ;update the clock HR:MIN:SEC
	BRA     L1

	RTS


RRTII
	LDX     #$6000          ;I/O BASE ADDRESS
	LDAA    #$40            ;clear RTIF
	STAA    TFLG2,X
	LDY     FSEC            ;count # of RTII
	INY                     ;occurrences
	STY     FSEC
	CPY     #FCNT           ;add 1 to SEC if 
	BEQ     SECONDS         ;enough occurred
	RTI

SECONDS
	CLR     FSEC            ;reset fraction sec count
	CLR     FSEC+1          ;to zero
	LDAA    SEC
	ADDA    #1              ;add 1 to seconds count
	DAA                     ;adjust for decimal arithmetic
	CMPA    #$60            ;check for seconds == 60
	BEQ     MINUTES         ;adjust minutes if == 60
	STAA    SEC
	RTI
MINUTES
	CLR     SEC             ;reset seconds to 0
	LDAA    MIN
	ADDA    #1              ;add 1 to minutes count
	DAA                     ;adjust for decimal arithmetic
	CMPA    #$60            ;check for minutes == 60
	BEQ     HOURS           ;and adjust hours if == 60
	STAA    MIN
	RTI
HOURS
	CLR     MIN             ;reset minutes count
	LDAA    HR
	ADDA    #1              ;add 1 to hours count
	DAA
	STAA    HR
	CMPA    #$24            ;check for hours == 24
	BNE     RETURN          ;and reset to 0 if == 24
	CLR     HR
RETURN
	RTI
	END

;routine to display HR,MIN,SEC
DISPLAY
	LDAA    HR
	TAB
	LSRA
	LSRA
	LSRA
	LSRA
	JSR     HX2ASCII
	STAA    $6040
	JSR     $9018
	TBA
	JSR     HX2ASCII
	STAA    $6040
	JSR     $9018
	LDAA    #':'
	STAA    $6040
	JSR     $9018
	LDAA    MIN
	TAB
	LSRA
	LSRA
	LSRA
	LSRA
	JSR     HX2ASCII
	STAA    $6040
	JSR     $9018
	TBA
	JSR     HX2ASCII
	STAA    $6040
	JSR     $9018
	LDAA    #':'
	STAA    $6040
	JSR     $9018
	LDAA    SEC     ;read the value of second in BCD
	TAB             ;transfer from accumulator A to accumulator B
	LSRA
	LSRA
	LSRA
	LSRA            ;shift 4 places to the right
	JSR     HX2ASCII
	STAA    $6040
	JSR     $9018
	TBA
	JSR     HX2ASCII
	STAA    $6040
	JSR     $9018
	LDAA    #$0D
	STAA    $6040
	JSR     $9018
	RTS

HX2ASCII ANDA #$0F
	 ADDA #$30              ;A contains ASCII equivalent to(0-9)
	 CMPA #$39
	 BHI AD7HEX
	 RTS
AD7HEX   ADDA #$7               ;A contains ASCII equivalent to (A-F)
	 RTS

	 END

