;DELAY.ASM   (AES-11 Sample Program)
;
;Shows use of the 68HC11 timer with a delay routine which can delay
;up 65535 seconds.  The delay routine uses the output compare
;register 2 to make a time delay. This is a simple delay routine only.
;When the routine is called from the main program it will take up
;most of the CPU time.  A more advanced routine would run in the background
;using interrupts while the main program continues to process other tasks.
;
;
;
;
LEDSON  EQU     $901B           ;AES11 's Rom routine to toggle LEDs on
LEDSOFF EQU     $901E           ;

IOBASE  EQU     $6000           ;BASE ADDRESS FOR CONTROL REGISTERS
TFLG1   EQU     $23             ;Main Timer Interrupt Flag Register 1
TCNT    EQU     $0E             ;Timer Counter Register
TOC2    EQU     $18             ;Timer Output Compare Register 2


        ORG $100
        
        LDY  #$3                ;setup IY for 3 seconds to
                                ;use with DELAY Subroutine
HOME
        JSR  LEDSON             ;toggle LEDs on
        JSR  DELAY              ;delay for 3 seconds
        JSR  LEDSOFF            ;toggle LEDS off
        JSR  DELAY
        BRA  HOME               ;continue flashing LEDS 

;***********************************************************************
;DELAY()
;subroutine uses a number in IY register to make a time delay in second(s)
;maximum delay time is 65535 seconds.

;To create a delay, add the amount of delaying time to the amount
;of time in the TCNT register.  Store that number into any of the
;output compare registers.  Whenever the time in TCNT equals the
;number in one of those output compare registers a compare has
;occurred and a flag will be set.  Each output compare register
;will have its flag set once every 71ms (AES11) when TCNT equals the 
;number in the compare register. So to have a flag set at every 50ms,
;add 50ms to the running value in TCNT. When a flag set, there
;is 50ms delayed already.  Flag set 20 times will have 1 second
;delay.  LOOP1 in the below program has 1 second delay. Outer LOOP
;is controled by IY register.  It will have up to 65535 seconds or 18hrs.

DELAY   
        PSHY                       
        PSHX
        PSHA
        PSHB
        LDX  #IOBASE               

loop
        LDAB    #$14               
                                   ;14H * 50msec = 1 second
loop1
        PSHB                       ;save register B on top of stack
        LDD     TCNT,X             ;get count in TCNT, adddress 600EH
        ADDD    #$C350             ;add 50msec (1.085uS/cycle * C340H)
        STD     TOC2,X             ;store the compare count in TOC2
        
        LDAA    #$40               ;
        STAA    TFLG1,X            ;clear OC2F flag in TFLG1

loop3   BRCLR   TFLG1,X #$40 loop3 
                                   ;wait for OC2F (bit 6 of TFLG1) set
        PULB                       ;restore B from stack and reduce
        DECB                       ;by 1
                                   ;after 20 times, we have 1 second delay
        BNE     loop1           
        DEY                        ;decrement IY
        BNE     loop               ;continue until IY = 0
        
        PULB
        PULA
        PULX
        PULY
        
        RTS                        ;end of DELAY Subroutine
;************************************************
