;DEMO11.ASM (AES11 Program)
;
;Assembler: AS11 Ver. 1.03
;Assembler Command Line: AS11 DEMO11.ASM
;
;program displays a menu with some test programs to run on the aes11 board.
;
;To run program at the Debugger Prompt, type
;P 0100 <enter>


;ROM routines'address 
LCDTEXT EQU     $902A           ;address of AES11 's driver which
                                ;sends text string null terminates;
                                ;indexes by IX to the LCD display

CRTTEXT EQU     $9027           ;similar to LCDTEXT, but send text
                                ;to the CRT display

AES_C   EQU     $6040           ;AES-11 'scratch memmory for use
                                ;with AES-11 I/O routines in ROM.

GETCHRE EQU     $9012           ;get the character from the PC 's
                                ;keyboard;

ADPE0   EQU     $9021           ;start A/D conversion at PORT E.0
                                ;and store result in 6040H
PUTCHAR  EQU  $9018    ;address of ROM routine which sends ASCII code in 
                       ;AES_C to the serial port.


        ORG     $100           ;program starts at 100H 
        
        JMP    MAIN
TEMPX   ZMB    1        

        ORG     $200

        ORG     $300

MAIN     LDX  #MENU         ;set IX point to the first character
                            ;of a menu-prompt string.

         JSR  CRTTEXT       ;call routine in ROM to display
                            ;the string indexes by IX to the CRT display.
            
         LDX  #CMDTAB       ;IX points to the command table
         LDAB #3            ;address between each command in the 
                            ;command table is separated by 3 bytes
                               

         JSR  $9012         ;call routine in ROM to read the
                               ;user input for the command selection.
                               ;routine reads input from the pc console
                               ;and stores in AES_C (6040H)
            
         LDAA AES_C        

         CMPA #$0D         ;if <enter> key is pressed, redisplay
                              ;the menu prompt
         BNE  LOOP         ;else looping though the command table,
                              ;and compare the user command to each
                              ;command in the table.
         BRA  MAIN

LOOP     CMPA 0,X
         BEQ  CALL       ;user command is equal to the command in the table
         TST  0,X        ;test for end of the command table
         BEQ  NOTFOUND   ;END OF TABLE
         ABX             ;add 3 to index X to get the address
                         ;of the next command in the table to be tested.
         BRA  LOOP       ;branch to test the command with the user command

NOTFOUND BSR  ERROR
         BRA  MAIN

ERROR    LDX #ERRTXT     ;*invalid choice*    
         JSR CRTTEXT
         RTS

CALL     LDX  1,X        ;add 1 to index X will get the address
                         ;of a subroutine for that particular command
         JSR  0,X        ;call subroutine indirectly. Address
                         ;of the routine is in IX.
            
         BRA  MAIN           



;sub-routine to toggle leds on
LEDSON  JSR $901B       ;use routine in ROM to toggle leds on
        RTS            

;sub-routine to toggle leds off
LEDSFF  JSR $901E       ;use routine in ROM to toggle leds off
        RTS

LCDCLS  JSR $9000       ;use routine in ROM to clear the LCD Display
        RTS

RDSND   LDX #RDTXT      ;message "Type in a line of text>"
        JSR CRTTEXT
        
        LDX #BUFFER     ;memory storage for the input string

RDNXT   JSR GETCHRE
        LDAA AES_C
        CMPA #$0D       ;is end of the input yet?
        BEQ  ENDREAD    ;yes. terminate a string with 0
        STAA 0,X         
        INX
        BRA RDNXT       ;get next character
ENDREAD CLRA
        STAA 0,X        ;terminate input string with a 0
        
        JSR $9000       ;use ROM routine to clear the LCD
        LDX #BUFFER   
        JSR LCDTEXT     ;send the input string to the LCD
        RTS

KEYCODE LDX #KEYTXT
        JSR CRTTEXT     ;message "press any key on the keypad"
        JSR $900F       ;use routine in ROM to get the hardware
                        ;keycode
        
        LDAA AES_C      ;read the code
        STAA TEMPX      ;save at a temporary variable in RAM
        
        LDX #KEYTXX     ;message "Hardware Keycode"
        JSR CRTTEXT     
        LDAA TEMPX
        LSRA            ;logical shift right
        LSRA            ;shift 4 times to the right
        LSRA
        LSRA
        JSR HX2ASCII    ;convert high nible to ASCII
        STAA AES_C      ;ASCII of high nible is stored in 6040h
        JSR $9018       ;use ROM routine to send ASCII code in
                        ;6040h to the CRT display.
        LDAA TEMPX      ;re-read the data
        JSR HX2ASCII    ;convert lower nible to ASCII
        STAA AES_C
        JSR $9018       ;send ASCII code  equivalent to lower nible
                        ;to the CRT display.
                        
        LDAA #'h'
        STAA AES_C
        JSR $9018       ;hardware keycode is displayed in hexadecimal
                        ;number
        RTS


;sub-routine to make D/A conversion
;use one-half of the maximum D value.

DACNV   LDAA #$7F       ;Digital value use in conversion
        STAA AES_C      
        JSR  $9024      ;ROM routine which reads the number.
                        ;in AES_C (6040h) and make D/A conversion
        LDX #DATEXT     ;message "D/A conversion done"
        JSR CRTTEXT
        RTS

;sub-routine to make D/A conversion
;use the maximum D value 
DACNV2  LDAA #$FF       ;Digital value use in conversion
        STAA AES_C
        JSR  $9024      ;ROM routine which read the number in AES_C
        LDX #DATEXT     ;(6040h) and make D/A conversion
        JSR CRTTEXT     ;message "D/A conversion done"
        RTS

;this routine will read A/D conversion at port E pin 0
;and return the floating number in IX
ADCNV   LDX #ADTEXT     ; message "Analog Reading = "
        JSR CRTTEXT
        LDX #BUFFER     ; initialize to store the A/D result
        JSR $9036       ; make A/D conversion
        JSR CRTTEXT     ; send result to the CRT
        RTS

SQUAREWV JSR $9030      ; use ROM routine to generate a square wave
         RTS

QUIT    LDAA #$0D       ;ASCII code for a carriage return
        STAA AES_C      
        JSR  $9018      ;send a carriage return to the CRT
        SWI             ;software interrupt; return to the Debugger.


HX2ASCII ANDA #$0F              
         ADDA #$30              ;A contains ASCII equivalent to(0-9)
         CMPA #$39
         BHI AD7HEX
         RTS
AD7HEX   ADDA #$7               ;A contains ASCII equivalent to (A-F)
         RTS

LOGDATA
        PSHX
        PSHB
        LDX #$200
        LDAB #$80               ;counting constant of 128 A/D readings

LAGAIN
        JSR ADPE0               ;read A/D conversion
        LDAA AES_C              ;load the result in A-register
        STAA 0,X                ;store in memmory
        INX                     ;advance pointer
        DECB
        BNE  LAGAIN
        PULB
        PULX
        RTS

SENDLOG
        PSHA
        PSHB
        PSHX
        JSR  NEWLINE        
        JSR  NEWLINE
        LDAB #$10       ;count down constant (16)
        LDX #$200       ;starting address of log data
NEXT        
        LDA 0,X         ;read data in memory
        PSHA            ;save on stack for later use again
        LSRA            ;Logical Shift Right 4 times
        LSRA
        LSRA
        LSRA            
        JSR   HX2ASCII  ;converts the high nible to ASCII
        STA   AES_C
        JSR   PUTCHAR
        PULA
        ANDA #$0F       ;strip the high nible 
        JSR  HX2ASCII   ;converts the lower nible to ASCII
        STA  AES_C
        JSR  PUTCHAR
        JSR  SPACE
        DECB
        BEQ   LINE      ;if 16 bytes sent, go and send a newline
CONT
        INX
        CPX  #$280
        BNE  NEXT
        
        PULX
        PULB
        PULA
        RTS             

LINE    JSR NEWLINE
        LDAB #$10
        BRA CONT


SPACE    PSHA
         LDAA #$20      
         STA AES_C
         JSR PUTCHAR
         PULA
         RTS

NEWLINE  PSHA
         LDAA #$0A
         STA AES_C
         JSR PUTCHAR
         LDAA #$0D
         STA AES_C
         JSR PUTCHAR
         PULA
         RTS


;******************************************************************
;command table contains the command code, and the address to its
;routine
;******************************************************************
CMDTAB  FCB    '1'
        FDB    LEDSON
        FCB    '2'
        FDB    LEDSFF
        FCB    '3'
        FDB    LCDCLS
        FCB    '4'
        FDB    RDSND
        FCB    '5'
        FDB    KEYCODE
        FCB    '6'
        FDB    DACNV
        FCB    '7'
        FDB    DACNV2
        FCB    '8'
        FDB    ADCNV
        FCB    '9'
        FDB    SQUAREWV
        FCB    'A'
        FDB    LOGDATA
        FCB    'B'
        FDB    SENDLOG
        FCB    'Q' 
        FDB     QUIT
        FCB    'q'
        FDB     QUIT
        FCB     0


;menu prompt
MENU    FCB   10,13,10,13
        FCC   '    Main Menu'
        FCB   10,13,10,13
        FCC   '1.  Toggle leds on.'
        FCB   10,13
        FCC   '2.  Toggle leds off.'
        FCB   10,13
        FCC   '3.  Clear the LCD.'
        FCB   10,13
        FCC   '4.  Read/Send a line of text string to the LCD display'
        FCB   10,13
        FCC   '5.  Read hardware keycode on the keypad.'
        FCB   10,13  
        FCC   '6.  D/A Conversion. Convert 7Fh to analog.'
        FCB   10,13
        FCC   '7.  D/A Conversion. Convert FFh to analog.'
        FCB    10,13
        FCC   '8.  Read A/D conversion at Port E pin 0'
        FCB   10,13
        FCC   '9.  Generate a 50Hz square wave at Port A pin 6 continuously'
        FCB   10,13
        FCC   'A.  Read A/D conversion for 128 times and store in memmory'
        FCB   10,13
        FCC   '    starting at 200H. (log data).'
        FCB   10,13
        FCC   'B.  Dump log data from memmory between 200H to 280H.'
        FCB   10,13
        FCC   'Q.  Quit'
        FCB   10,13,10,13
        FCC   'Enter choice: '
        FCB    0

RDTXT   FCB   10,13
        FCC   'Type in a line of text string >'
        FCB   10,13
        FCB   0

ERRTXT  FCB 10,13
        FCC '*invalid choice*'
        FCB 10,13,0
KEYTXT  FCB 10,13
        FCC 'PRESS ANY KEY ON THE KEY PAD>'
        FCB 0

KEYTXX  FCB 10,13
        FCC 'Hardware Keycode = '
        FCB 0
DATEXT  FCB 10,13
        FCC 'D/A CONVERSION DONE'
        FCB 0
ADTEXT  FCB 10,13
        FCC 'Analog reading = '
        FCB 0

BUFFER  ZMB    80       ;allocate 80 bytes of storage

        END

