;FLOAT2.ASM (AES11 Sample Program)

;Program illustrates UINT2FLT Routine.  The UINT2FLT Routine performs
;unsigned integer to floating point conversions of a 16 bit word.
;The 16 bit integer must be in the lower 16 bits of FPACC1 mantisa.
;In the AES-11, the memory format for FPACC1 looks similar to
;the following figures:
;
; Address:    6100          6101    6102     6103            6104              
;             FPACCEX         MANTISA (3 BYTES)           MANTISA SIGN
;
; Therefore, the lower 16 bit word of the mantisa starts at 6102Hex
;
; The program is to write a 16 bit word ( two bytes)  into locations
; 6102 and 6103.

;Assembler: AS11 Ver. 1.03
;Assembler Commands: AS11 FLOAT2.ASM
;
;To run program at the Debugger Prompt, type
;B 0100 <enter>

; Assembler 's Directives (EQU's, ORG's)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; ADDRESSES OF FLOATING ROUTINES IN ROM.                             ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

UINT2FLT        EQU     $9065   ;Unsigned integer to floating point.
FLTASC          EQU     $905F   ;Floating-Point to ASCII Conversion.                        

;*********************************************************************
CRTTEXT EQU  $9027              ;ADDRESS OF AES ROUTINE WHICH SENDS TEXT
                                ;STRING TO THE CRT DISPLAY.
;*********************************************************************

        ORG $100               ;Program starts in external RAM at 100Hex.
        JMP MAIN               ;jump to program 's main codes.

BUFFER  ZMB 14                 ;reserved 14 bytes of memory for storage
                               ;of the result.
                               
        ORG $200                
MAIN:   LDD #$9AFF             ;Load D-Register with 9AFFHex (39679 dec.)
                               ;or any number up to 64K

                               ;Write a 16 bit interger to the lower
                               ;16 bit of the mantisa.
        STD $6102              ;[$6102] <- A ; [$6103] <- B , A+B=D                           

        JSR  UINT2FLT          ;unsigned integer to floating point.

        LDX  #BUFFER           ;set IX to BUFFER.
        JSR  FLTASC            ;float to ascii conversion.

        LDX  #BUFFER           ;send result in ASCII Format
        JSR  CRTTEXT           ;to the CRT display.
        RTS                    ;program ends and returns to the Debugger.

        END
