;FLOAT3.ASM (AES11 Program)
;
;Program calls the built-in routine to perform A/D conversion at PORTE.0.
;After reading the D value from the conversion, program multiplies
;D value by a constant number (.01937) in order to get the corresponding
;analog input at PORTE.0 pin.

;Analog Input = D * Resolution
;Resolution = VRh-VRl /(2^8) = Apx. 19.37mV on our AES11 Board.
;
;program execution:
;                       1) use built-in routine to perform A/D conversion.
;                       2) use floating-point routines to calculate
;                          analog input.
;                       3) output analog result to the CRT Display.

;AS11.EXE FLOAT3.ASM

;From the debugger menu:
;B 0100 

;Assembler: AS11 Ver. 1.03
;Assembler Commands: AS11 FLOAT3.ASM
;
;To run program at the Debugger Prompt, type
;B 0100 <enter>

; Assembler 's Directives (EQU's, ORG's)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; ADDRESSES OF FLOATING ROUTINES IN ROM.                             ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

UINT2FLT        EQU     $9065   ;Unsigned integer to floating point.
ASCFLT          EQU     $9050   ;Ascii to float conversion.
FLTASC          EQU     $905F   ;Floating-Point to ASCII Conversion.
TFR1TO2         EQU     $906E   ;Routine to transfer FPACC1 to FPACC2.
FLTMUL          EQU     $9053   ;Floating-Point Multiply.

;*********************************************************************
MAN2    EQU     $6102           ;Address of FPACC1 's second-byte mantissa
MAN3    EQU     $6103           ;Address of FPACC1 's third-byte mantissa


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; ADDRESSES OF AES ROUTINES IN ROM                                   ;   
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

ADPE0   EQU  $9021              ;Routine which starts A/D conversion
                                ;and stores result in memory 6040H.


CRTTEXT EQU  $9027              ;ADDRESS OF AES ROUTINE WHICH SEND TEXT
                                ;STRING TO THE CRT DISPLAY.

;*********************************************************************

        ORG $100               ;Program starts in external RAM at 100Hex.
        JMP MAIN               ;jump to program 's main codes.

BUFFER  ZMB 14                 ;reserved 14 bytes of memory for storage.

CONST1  FCC '1.937E-2'
        FCB 0                  ;notice we end text strings with a null

PROMPT  FCC 'Analog = '
        FCB 0
                               
        ORG $200                
MAIN:

        CLR MAN2        ;clear the lower 16 bit of FPACC1 's mantissa.
        CLR MAN3        ;

        JSR  ADPE0      ;start A/D conversion
        LDAA $6040      ;read A/D result at location 6040H
                        ;
        STAA MAN3       ;store D value into the lower 16 bit integer
                        ;of the mantissa

        JSR UINT2FLT    ;convert D to float

        JSR TFR1TO2     ;transfer D value to FPACC2


        LDX #CONST1     ;convert ascii string constant to float.
        JSR ASCFLT

        JSR FLTMUL      ;Analog = D * Resolution

        LDX  #BUFFER    ;set IX to BUFFER.
        JSR  FLTASC     ;float to ascii conversion.

        LDX  #BUFFER    ;send result in ASCII Format
        JSR  CRTTEXT    ;to the CRT display.

        RTS             ;program ends and returns to the Debugger.

        END
