;IC3.ASM
;PROGRAM TO MEASURE THE PULSE WIDTH OF A SQUARE WAVE CONNECTED
;TO PA2/IC1 AND PA1/IC2
;SYSOP:  CAPTURE ON RISING EDGE AT PA2 (IC1) FIRST THEN
;        CAPTURE ON FALLING EDGE AT PA1 (IC2)

;valid square wave: 20Hz-50KHz
;notes: xcrytal - 3.6864 MHz 

;Assembler: AS11 Ver. 1.03
;AS11.EXE IC3.ASM
;To run program at debugger menu 's prompt:
;G 0100 <enter>


TCTL2   EQU     $21             ;TIMER CONTROL REGISTER 2
TFLG1   EQU     $23             ;MAIN TIMER INTERRUPT FLAG REGISTER 1
TIC1    EQU     $10             ;TIMER INPUT CAPUTER 1
TIC2    EQU     $12             ;TIMER INPUT CAPTURE 2
        
        ORG     $100
        JMP     MAIN            
        
        ORG     $200

FIRST   FDB    ;capture # of count of the timer counter on the 1st
               ;falling edge of the input wave

SECOND  FDB    ;capture # of count of the timer counter on the 2nd
               ;falling edge of the input wave

RESULT  FDB    ;difference between # of count
               ;this no. of count  times 1.085uS per count will give the 
               ;actual time in second for HALF period of the input 
               ;square wave
               
MAIN            
        LDX     #$6000          ;BASE ADDRESS OF I/O REGISTERS
        LDAA    #$18            ;EDG1B:EDG1A = 0:1; IC1 RISING EDGE
                                ;EDG2B:EDG2A = 1:0; IC2 FALLING EDGE
        STAA    TCTL2,X 

        LDAA    #$7
        STAA    TFLG1,X         ;CLEAR ANY PENDING FLAGS (IC1F, IC2F )


LOOP1   BRCLR   TFLG1,X #$04 LOOP1     ;WAIT FOR RISING EDGE (IC1F SETS)

LOOP2   BRCLR   TFLG1,X #$02 LOOP2     ;WAIT FOR FALLING EDGE (IC2F SETS)
        

        LDD     TIC1,X              ;GET TIME OF FIRST EDGE
        STD     FIRST

        LDD     TIC2,X              ;GET TIME OF SECOND
        STD     SECOND

        SUBD    FIRST               ;Subtract the difference
        STD     RESULT
        
        RTS                   

        END

