;File RTI1.ASM is a test delay program for delay in background of
;1 to 255 minutes while Main program is running.  Main program will
;be interrupted for a few microseconds every 8.89 milliseconds.
;The 8.89 figure is only for the AES-11 board with its 3.6864 MHz Xtal.
;We could change this to make a interrupt only every 70 milliseconds
;by using RTR1 and RTR0 in the PACTL register (see ch. 10 in 68HC11 manual).
;This example program uses a 10 minute delay. You can change the minutes
;by changing the number in the NEXT2 routine.
TMSK2   EQU     $6024
TFLG2   EQU     $6025
;FOUR MEMORY VARIABLES FOR PROGRAM STORED IN UNUSED PART OF LOW RAM
;(unused part of RAM for THIS program, not unused in gereral, actually
;it is overwriting other interrupt vectors)
MEM1    EQU     $D3
MEM2    EQU     $D4
MEM3    EQU     $D5
MEM4    EQU     $D6
;ADDRESS OF RTI IN AES-11 (JUMP+ADDRESS) IS $EB+$EC+$ED
        ORG     $0100   ;LOAD PROGRAM HERE FOR AES-11 DEBUGGER
        CLRA
        STAA    MEM1    ;SET VARIABLES TO ZERO
        STAA    MEM2
        STAA    MEM3
        STAA    MEM4
        LDAA    #$7E    ;PUT IN JUMP TO $1200 AT RTI VECTOR LOCATION
        STAA    $EB     ;IN LOW RAM ON AES-11
        LDAA    #$12    ;7E IS THE MACHINE CODE FOR JMP
        STAA    $EC
        LDAA    #$00
        STAA    $ED
        JSR     $901E   ;MAKE SURE THE AES-11 LEDS ARE OFF
        CLI             ;CLEAR (GLOBAL ENABLE) INTERRUPTS
        LDAA    #$40
        STAA    TMSK2   ;ENABLE RTI INTERRUPT
        JMP     MAIN
;START MAIN PROGRAM AT $0300
        ORG     $0300
MAIN    NOP             ;DUMMY PROGRAM, JUST LOOPS FOREVER
        NOP
        JMP     MAIN
;PLACE INTERRUPT ROUTINE AT $1200
        ORG     $1200
NEXT0   LDAA    #$40
        STAA    TFLG2   ;CLEAR RTI FLAG
        INC     MEM1    ;MEM1 GOES UP 1 EACH TIME THERE IS AN INTERRUPT
        LDAA    MEM1
        CMPA    #225    ;BREAKS OUT AFTER 225 INTERRUPTS
        BEQ     NEXT1   ;225 TIMES 8.89MILLISEC = 2 SEC (WELL,CLOSE)
        RTI
NEXT1   CLRA
        STAA    MEM1    ;SET MEM1 BACK TO 0
        INC     MEM2    ;MEM2 GOES UP 1 FOR EACH 225 INTERRUPTS
        LDAA    MEM2
        CMPA    #30     ;BREAKS OUT IN 30 TIMES 2 SEC = 1 MIN
        BEQ     NEXT2
        RTI
NEXT2   CLRA
        STAA    MEM2    ;SET MEM2 BACK TO 0
        INC     MEM3    ;MEM3 GOES UP 1 FOR EACH 225*30 INTERRUPTS
        LDAA    MEM3     ;10 minute delay in this example
        CMPA    #10      ;PUT THE MINUTES OF TOTAL DELAY HERE
        BEQ     NEXT3    ;CAN BE 1 TO 255 MINUTES
        RTI
;AT THE END OF THE TOTAL DELAY WE JUST TURN ON THE LEDS TO SHOW IT
;WORKS, DISABLE INTERRUPTS, AND THEN RETURN TO THE MAIN PROGRAM
;WHICH WILL CONTINUE TO LOOP FOREVER WITHOUT INTERRUPTS
NEXT3   CLRA
        STAA    MEM3    ;MEM3 = 0
        JSR     $901B   ;TURN ON AES-11 LEDS
        SEI             ;SET (DISABLE) INTERRUPTS
        RTI
        END

