;THERMO.ASM 
;8/19/96
;AES-11 ' Sample Program related to Electronic Thermometer example
;in chapter 8 of the User's Manual
;
;Assemble and Run Program:
;AS11 THERMO.ASM
;B 0100

;program makes A/D reading at PE.0 pin and converts it to temperature
;in Fahrenheit.  Program will display the temperature on the LCD
;diplay.  Formula to convert, F = 300 - 1.7 * X, where F is the 
;temperature in  Fahrenheit and X is the A/D analog number between 
;0 and 255.


;program uses built-in floating-point routines, and other ROM routines.
;
;ROM routines used:
;           
;
; $902A, Sends text string indexed by IX; ended with null byte to
;        the LCD.
;
; $9000, routine to clear the LCD Display.
; $9021, A/D conversion at PE.0 pin

;
; Addresses of ROM routines on the AES-11 board.

LCDCLS  EQU $9000       ;clear LCD display
LCDTEXT EQU $902A       ;send ASCII string to the LCD.
ADPE0   EQU $9021       ;A/D conversion at PE.0 pin


;Addresses of floating-point routines
;see user's manual page 7-5

ASCFLT  EQU $9050       ;ASCII TO FLOAT CONVERSION
FLTMUL  EQU $9053       ;FLOATING-POINT MULTIPLY
FLTSUB  EQU $9059       ;FLOATING-POINT SUBTRACT
FLTASC  EQU $905F       ;FLOATING-POINT TO ASCII CONVERSION
TFR1TO2 EQU $906E       ;TRANSFER FLOATING-POINT ACCUMULATOR #1 (FPACC1)
                        ;TO FLOATING-POINT ACCUMULATOR #2 (FPACC2)

UINT2FLT EQU $9065      ;UNSIGNED INTEGER TO FLOATING-POINT

                        ;see user 's manual page 7-6 for floating
                        ;point format of FPACC1

                        ;FPACC1 contains 5 bytes starting at $6100
EXPONENT EQU $6100      ;ADDRESS of FPACC1 's exponent
MAN1     EQU $6101      ;Address of first byte mantissa
MAN2    EQU $6102       ;Address of the second-byte mantissa
MAN3    EQU $6103       ;Address of the third-byte mantissa
SIGN    EQU $6104       ;Address of the byte which indicated the
                        ;mantissa sign



        ORG     $100            ;program starts at 100Hex
        JMP     MAIN            ;jump to program 's main code.


                                ;section in RAM to stored
                                ;data, buffer, variables, etc
                                
RESLTN  FCC '19.37E-3'          ;ASCII format for 19.37mV
        FCB 0                   ;a string of ASCII ending with a 0 byte

                                
CONST1  FCC '1.7'           
        FCB 0                   ;ASCII format for constant-1

CONST2  FCC '300'
        FCB 0                   ;ASCII format for constant-2
                                
F_TMP   ZMB     20              ;Reversed 20 byte of data for
                                ;storing of the temperature
                                ;in Fahrenheit.
                                ;F_TMP = 300 - 1.7 * X


        ORG     $300
MAIN
        JSR     ADPE0           ;read A/D conversion; result in $6040
        LDAA    $6040           ;read result

                                ;now we want to convert the hexadecimal
                                ;number into floating-point number.
                                ;we can use the floating-point routine,
                                ;UINT2FLT
                                ;see chapter 7 in the User's Manual
                                
                                
                                ;since the mantissa is 3 bytes and
                                ;the A/D reading needs only 1 byte,
                                ;we need to write zeros into bytes
                                ;that we will not use.

        CLR     EXPONENT        ;clear the exponent of FPACC1
        CLR     MAN1            ;clear the first byte of the mantissa
        CLR     MAN2            ;clear the second byte of the mantissa
        CLR     SIGN            ;clear the sign
        
        
        STAA    MAN3            ;store the A/D conversion value
                                ;into the third-byte of the mantissa

                                ;convert unsigned integer to floating-point
        JSR     UINT2FLT        ;convert A/D value to floating-point
                                ;floating-point number is in FPACC1
        JSR     TFR1TO2         ;Transfer to FPACC2


                                ;now we want to multiply FPACC1 * 1.7

        LDX     #CONST1         ;LOAD IX with the address for 1.7
        JSR     ASCFLT          ;convert ASCII 1.7 to floating-point
                                ;FPACC1 now has a floating-point number
                                ;for 1.7
        
        JSR     FLTMUL          ;1.7 * X
                                ;FPACC1 = FPACC1 * FPACC2

        JSR     TFR1TO2         ;transfer the result of (1.7 * X)
                                ;to FPACC2

                                ;next step is to subtract the
                                ;product of (1.7 * X) from 300

        LDX     #CONST2         ;LOAD IX with 300
        JSR     ASCFLT          ;Convert ASCII '300' to floating-point
                                ;number.  Floating-point of '300'
                                ;now in FPACC1.

                                ;FPACC1 = FPACC1 - FPACC2
        JSR     FLTSUB          ;FPACC1 = 300 - (1.7*X)

                                ;FPACC2 now contains the floating-
                                ;point number of the temperature
                                ;in Fahrenheit.

                                ;we need to convert the number in
                                ;FPACC2 to ASCII String in order to
                                ;sent it out to the LCD display.

                                ;
                                ;
        LDX     #F_TMP          ;set IX to the beginning address
                                ;of string F_TMP.

        JSR     FLTASC          ;convert FLOATING_POINT to ASCII.
                                ;F_TMP now contains the temperature 
                                ;in Fahrenheit.

        JSR     LCDCLS          ;clear the LCD DISPLAY
        JSR     LCDTEXT         ;print out the temperature in Fahrenheit

        RTS                        



