/* aes11.c                                                   */
/* aes11.c contains functions to use with the aes11 board    */
/* functions interface with assembly routines resided in ROM */    
/* last updated: 5/31/1996                                   */
/*                                                           */
/* to generate an assembly file from a C file:               */
/* icc11 -S aes11.c                                          */

int ADC();               /* read A/D conversion at Port E. pin.0*/
void LEDS_ON();          /* toggle 6 LEDs ON                    */
void LEDS_OFF();         /* toggle 6 LEDs OFF                   */
void LCDCLEAR();         /* clear LCD display                   */
int  KEYCODE();          /* return the hardware scancode        */
                         /* of 00-13H for the key on the keypad */
void DAC(int x);         /* D/A conversion out on DA OUT        */

int GETCHAR();          /* get characater from the 1st serial port*/

void NEWLINE();         /* function which sends CR + LF to the serial */            
                        /* port                                        */

int ADC()
{
        asm(" jsr $9021");      /* call assembly routine in ROM      */
                                /* to start A/D conversion at        */
                                /* PORTE.0 and store result in 6040h */
        asm(" clra");
        asm(" ldab $6040");     /* get the result                    */

}

void LEDS_ON()
{
        asm (" jsr $901B");
}

void LEDS_OFF()
{
        asm (" jsr $901E");
}

void LCDCLEAR()
{
        asm (" jsr $9000");
}

int KEYCODE()           
{
        asm(" jsr $900F");      /* call assembly routine in ROM         */
                                /* to read the hardware scan code (0-19)*/

        asm(" clra");
        asm(" ldab $6040");     /* get the result               */
}

void DAC(int x)                 /* D/A conversion routine       */
{       
      
       asm (" ldd %x");        /* pass int x to D-accumulator   */
       asm (" stab $6040");    /*                               */
       asm (" jsr $9024");     /* call routine in ROM to read   */
                                /* the value in 6040h and make  */
                                /* D/A conversion                */
}

int GETCHAR() {

        asm (" JSR $9012");     /* call ROM routine to receive character */
                                /* from the 1st serial port              */
                                /* routine stores character in 6040H     */

        asm (" clra");          /* clear A-accumulator                   */
        asm (" ldab $6040");    /* read character at 6040H               */
                                /* GETCHAR returns value in D register   */
}

void NEWLINE()
{
        asm(" ldaa #$0d");      /* ASCII CODE a carriage return */
        asm(" staa $6040");     /* store in 6040H               */
        asm(" jsr $9018");      /* ROM routine in 9018H which sends     */
                                /* ASCII in 6040H out to the 1st serial */
                                /* port                                 */
        asm(" ldaa #$0a");
        asm(" staa $6040");     /* do the same for LF                   */
        asm(" jsr $9018");
}
